@@ -1,10 +1,10 @@
 package Bundle::SPOPS;
 
-# $Id: SPOPS.pm,v 1.8 2001/12/31 05:35:22 lachoy Exp $
+# $Id: SPOPS.pm,v 1.10 2002/01/15 11:54:32 lachoy Exp $
 
 use strict;
 
-$Bundle::SPOPS::VERSION = '1.08';
+$Bundle::SPOPS::VERSION = '1.09';
 
 1;
 
@@ -30,8 +30,14 @@ Storable (1.00)
 
 Class::Date (1.00)
 
+Carp::Assert
+
+Class::Fields
+
 Class::Accessor
 
+Devel::StackTrace
+
 SPOPS
 
 =head1 DESCRIPTION
@@ -39,14 +45,14 @@ SPOPS
 Install the few modules needed for SPOPS. Note that this is the bare
 minimum -- to actually do something with the module you are probably
 going to need at least L<DBI> plus one or more of the supported DBD
-drivers (like L<DBD::mysql>, L<DBD::Sybase>, L<DBD::ASAny>). You can
-also currently use SPOPS with L<GDBM_File>.
+drivers (like L<DBD::mysql>, L<DBD::Sybase>, L<DBD::ASAny>, L<DBD::Pg>
+or L<DBD::ODBC>). You can also currently use SPOPS with L<GDBM_File>.
 
 =head1 MORE INFORMATION
 
-Information on the web about this module is found with OpenInteract,
-even though SPOPS is self-contained and is very useful outside of
-OpenInteract.
+Information on the web about this module is found with OpenInteract, a
+web-application server. Don't let that scare you: SPOPS is
+self-contained and is very useful outside of OpenInteract.
 
 Sourceforge Project Home:
 
@@ -56,6 +62,13 @@ News, package repository and more information:
 
  http://www.openinteract.org/
 
+=head1 COPYRIGHT
+
+Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =head1 AUTHORS
 
 Chris Winters <chris@cwinters.com>
